OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Невозможно выполнить запись в каталог «config».",
    "This can usually be fixed by giving the web server write access to the config directory." : "Обычно эту ошибку можно исправить, предоставив веб-серверу права на запись в каталог конфигурации.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Если для файла «config.php» должен быть установлен режим «только чтение», задайте параметру «config_is_read_only» значение «true».",
    "See %s" : "Обратитесь к %s.",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Приложение %1$s отсутствует или его версия несовместима с этим сервером. Пожалуйста, проверьте каталог приложений.",
    "Sample configuration detected" : "Обнаружена конфигурация из примера.",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Была обнаружена конфигурация из примера. Такая конфигурация не поддерживается и может повредить вашей системе. Прочтите документацию перед внесением изменений в файл config.php",
    "The page could not be found on the server." : "Страница не найдена на сервере.",
    "%s email verification" : "Проверка почтового адреса %s",
    "Email verification" : "Подтверждение адреса электронной почты",
    "Click the following button to confirm your email." : "Нажмите на кнопку чтобы подтвердить свой адрес электронной почты.",
    "Click the following link to confirm your email." : "Перейдите по ссылке чтобы подтвердить свой адрес электронной почты.",
    "Confirm your email" : "Подтвердить адрес электронной почты",
    "Other activities" : "Другие события",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Education Edition" : "Набор приложений для образовательных учреждений",
    "Enterprise bundle" : "Набор приложений для предприятий",
    "Groupware bundle" : "Набор приложений для совместной работы",
    "Hub bundle" : "Основной набор приложений",
    "Social sharing bundle" : "Набор приложений для публикации с использованием соц. сетей",
    "PHP %s or higher is required." : "Требуется PHP версии %s или выше.",
    "PHP with a version lower than %s is required." : "Требуется PHP версии ниже %s.",
    "%sbit or higher PHP required." : "Требуется PHP с разрядностью %s бит или более.",
    "The following architectures are supported: %s" : "Поддерживаются следующие архитектуры: %s",
    "The following databases are supported: %s" : "Поддерживаются следующие базы данных: %s",
    "The command line tool %s could not be found" : "Утилита командной строки %s не найдена",
    "The library %s is not available." : "Библиотека «%s» недоступна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Требуется библиотека «%1$s» версии не меньше %2$s, установлена версия %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Требуется библиотека «%1$s» версии не выше %2$s, установлена версия %3$s.",
    "The following platforms are supported: %s" : "Поддерживаются следующие платформы: %s",
    "Server version %s or higher is required." : "Требуется сервер версии %s или выше.",
    "Server version %s or lower is required." : "Требуется сервер версии %s или ниже.",
    "Wiping of device %s has started" : "Удаление данных с устройства «%s».",
    "Wiping of device »%s« has started" : "Удаление данных с устройства «%s».",
    "»%s« started remote wipe" : "Начало удаления данных с устройства «%s»",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "На устройстве или в приложении «%s» был начат процесс удаления данных. После его завершения будет отправлено ещё одно электронное письмо.",
    "Wiping of device %s has finished" : "Удаление данных с устройства  «%s» завершено.",
    "Wiping of device »%s« has finished" : "Удаление данных с устройства «%s» завершено.",
    "»%s« finished remote wipe" : "Удаление данных с устройства «%s» завершено",
    "Device or application »%s« has finished the remote wipe process." : "Процесс удаления данных на устройстве или в приложении «%s» завершён.",
    "Remote wipe started" : "Запущен процесс удаления данных с устройства",
    "A remote wipe was started on device %s" : "Запущен процесс удаления данных с устройства «%s»",
    "Remote wipe finished" : "Процесс удаления данных с устройства завершён",
    "The remote wipe on %s has finished" : "Процесс удаления данных с устройства «%s» завершён",
    "Authentication" : "Аутентификация",
    "Unknown filetype" : "Неизвестный тип файла",
    "Invalid image" : "Изображение повреждено",
    "Avatar image is not square" : "Изображение аватара не квадратное",
    "Files" : "Файлы",
    "View profile" : "Открыть профиль",
    "Local time: %s" : "Местное время: %s",
    "today" : "сегодня",
    "tomorrow" : "завтра",
    "yesterday" : "вчера",
    "_in %n day_::_in %n days_" : ["через %n день","через %n дня","через %n дней","через %n дня"],
    "_%n day ago_::_%n days ago_" : ["%n день назад","%n дня назад","%n дней назад","%n дня назад"],
    "next month" : "в следующем месяце",
    "last month" : "в прошлом месяце",
    "_in %n month_::_in %n months_" : ["через %n месяц","через %n месяца","через %n месяцев","через %n месяца"],
    "_%n month ago_::_%n months ago_" : ["%n месяц назад","%n месяца назад","%n месяцев назад","%n месяца назад"],
    "next year" : "в следующем году",
    "last year" : "в прошлом году",
    "_in %n year_::_in %n years_" : ["через %n год","через %n года","через %n лет","через %n года"],
    "_%n year ago_::_%n years ago_" : ["%n год назад","%n года назад","%n лет назад","%n года назад"],
    "_in %n hour_::_in %n hours_" : ["через %n час","через %n часа","через %n часов","через %n часа"],
    "_%n hour ago_::_%n hours ago_" : ["%n час назад","%n часа назад","%n часов назад","%n часа назад"],
    "_in %n minute_::_in %n minutes_" : ["через %n минуту","через %n минуты","через %n минут","через %n минуты"],
    "_%n minute ago_::_%n minutes ago_" : ["%n минуту назад","%n минуты назад","%n минут назад","%n минуты назад"],
    "in a few seconds" : "через несколько секунд",
    "seconds ago" : "несколько секунд назад",
    "Empty file" : "Пустой файл",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль с ID «%s» не существует. Включите его в настройках приложений или обратитесь к администратору.",
    "File already exists" : "Файл уже существует",
    "Invalid path" : "Некорректный путь",
    "Failed to create file from template" : "Не удалось создать файл на основе шаблона",
    "Templates" : "Шаблоны",
    "File name is a reserved word" : "Имя файла является зарезервированным словом",
    "File name contains at least one invalid character" : "Имя файла содержит по крайней мере один недопустимый символ",
    "File name is too long" : "Имя файла слишком длинное.",
    "Dot files are not allowed" : "Файлы начинающиеся с точки не допускаются",
    "Empty filename is not allowed" : "Пустое имя файла не допускается",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Приложение «%s» не может быть установлено, так как файл с информацией о приложении не может быть прочтен.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Приложение «%s» не может быть установлено, потому что оно несовместимо с этой версией сервера",
    "__language_name__" : "Русский",
    "This is an automatically sent email, please do not reply." : "Это сообщение отправлено автоматически и не требует ответа.",
    "Help" : "Помощь",
    "Appearance and accessibility" : "Внешний вид и доступность",
    "Apps" : "Приложения",
    "Personal settings" : "Личные настройки",
    "Administration settings" : "Параметры сервера",
    "Settings" : "Настройки",
    "Log out" : "Выйти",
    "Users" : "Пользователи",
    "Email" : "Адрес эл. почты",
    "Mail %s" : "Написать %s",
    "Fediverse" : "Федиверс",
    "View %s on the fediverse" : "Открыть %s в Федиверс",
    "Phone" : "Телефон",
    "Call %s" : "Позвонить %s",
    "Twitter" : "Твиттер",
    "View %s on Twitter" : "Посмотреть профиль %s в Твиттере",
    "Website" : "Сайт",
    "Visit %s" : "Посетить сайт %s",
    "Address" : "Адрес",
    "Profile picture" : "Изображение профиля",
    "About" : "О себе",
    "Display name" : "Отображаемое имя",
    "Headline" : "Заголовок",
    "Organisation" : "Организация",
    "Role" : "Роль",
    "Additional settings" : "Дополнительные настройки",
    "Enter the database name for %s" : "Укажите название базы данных %s",
    "You cannot use dots in the database name %s" : "Имя базы данных %s не может содержать символ точки",
    "You need to enter details of an existing account." : "Необходимо уточнить данные существующего акаунта.",
    "Oracle connection could not be established" : "Соединение с Oracle не может быть установлено",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не поддерживается и %s может работать некорректно на данной платформе. Используйте на свой страх и риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
    "Set an admin password." : "Задать пароль для admin.",
    "Cannot create or write into the data directory %s" : "Не удалось создать или записать в каталог данных «%s»",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бэкенд общего доступа %s должен реализовывать интерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Механизм предоставления общего доступа %s не найден",
    "Sharing backend for %s not found" : "Не найден механизм предоставления общего доступа для %s ",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s предоставил(а) вам доступ к «%2$s» и хочет добавить:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s предоставил(а) вам доступ к «%2$s» и хочет добавить",
    "»%s« added a note to a file shared with you" : "%s добавил(а) примечание к файлу, к которому вам открыт доступ",
    "Open »%s«" : "Открыть «%s»",
    "%1$s via %2$s" : "%1$s через %2$s",
    "You are not allowed to share %s" : "Вам не разрешено делиться %s",
    "Cannot increase permissions of %s" : "Не удалось повысить права доступа %s",
    "Files cannot be shared with delete permissions" : "Права на удаление файлов не позволяют открывать общий доступ к ним",
    "Files cannot be shared with create permissions" : "Права на создание файлов не позволяют открывать общий доступ к ним",
    "Expiration date is in the past" : "Дата окончания срока действия уже прошла",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Срок окончания не может быть более %n дня","Срок окончания не может быть более %n дней","Срок окончания не может быть более %n дней","Срок окончания не может быть более %n дней"],
    "Sharing is only allowed with group members" : "Разрешено публиковать только для участников группы",
    "%1$s shared »%2$s« with you" : "%1$s предоставил(а) вам доступ к «%2$s»",
    "%1$s shared »%2$s« with you." : "%1$s предоставил(а) вам доступ к «%2$s».",
    "Click the button below to open it." : "Нажмите расположенную ниже кнопку для перехода к полученному общему ресурсу.",
    "The requested share does not exist anymore" : "Запрошенный общий ресурс более не существует.",
    "The requested share comes from a disabled user" : "Запрос на общий доступ поступает от отключенного пользователя",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Пользователь не был создан, достигнуто ограничение количества пользователей. Для получения дополнительных сведений проверьте уведомления.",
    "Could not find category \"%s\"" : "Категория «%s»  не найдена",
    "Sunday" : "Воскресенье",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sun." : "Вс.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Вс",
    "Mo" : "Пн",
    "Tu" : "Вт",
    "We" : "Ср",
    "Th" : "Чт",
    "Fr" : "Пт",
    "Sa" : "Сб",
    "January" : "Январь",
    "February" : "Февраль",
    "March" : "Март",
    "April" : "Апрель",
    "May" : "Май",
    "June" : "Июнь",
    "July" : "Июль",
    "August" : "Август",
    "September" : "Сентябрь",
    "October" : "Октябрь",
    "November" : "Ноябрь",
    "December" : "Декабрь",
    "Jan." : "Янв.",
    "Feb." : "Фев.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Май",
    "Jun." : "Июн.",
    "Jul." : "Июл.",
    "Aug." : "Авг.",
    "Sep." : "Сен.",
    "Oct." : "Окт.",
    "Nov." : "Нояб.",
    "Dec." : "Дек.",
    "A valid password must be provided" : "Укажите допустимый пароль",
    "Login canceled by app" : "Вход отменен приложением",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложение «%1$s» не может быть установлено, так как не удовлетворены следующие зависимости: %2$s",
    "a safe home for all your data" : "надёжный дом для всех ваших данных",
    "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
    "Cannot download file" : "Не удалось скачать файл",
    "Application is not enabled" : "Приложение не разрешено",
    "Authentication error" : "Ошибка аутентификации",
    "Token expired. Please reload page." : "Токен просрочен. Перезагрузите страницу.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не установлены драйвера баз данных (sqlite, mysql или postgresql)",
    "Cannot write into \"config\" directory." : "Невозможно выполнить запись в каталог «config».",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в каталог конфигурации. Обратитесь к %s.",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Если для файла «config.php» должен быть установлен режим «только чтение», задайте параметру \"config_is_read_only\" значение \"true\". Изучите %s.",
    "Cannot write into \"apps\" directory." : "Не удалось выполнить запись в каталог «apps».",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Обычно это можно исправить, предоставлением веб-серверу права для записи в каталог приложений или отключением магазина приложений в файле конфигурации.",
    "Cannot create \"data\" directory." : "Невозможно создать каталог «data».",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в корневой каталог. Обратитесь к %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Разрешения обычно можно исправить, предоставив веб-серверу право на запись в корневой каталог. Обратитесь к %s.",
    "Your data directory is not writable." : "Каталог данных недоступен для записи.",
    "Setting locale to %s failed." : "Не удалось настроить локаль %s.",
    "Please install one of these locales on your system and restart your web server." : "Установите один из этих языковых пакетов и перезапустите веб-сервер.",
    "PHP module %s not installed." : "Не установлен PHP-модуль %s.",
    "Please ask your server administrator to install the module." : "Попросите администратора сервера установить этот модуль.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметру PHP «%s» не присвоено значение «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Настройка этого параметра в файле php.ini восстановит работоспособность Nextcloud",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Параметр <code>mbstring.func_overload</code> установлен в <code>%s</code>, но ожидается значение <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Чтобы исправить эту проблему установите параметр <code>mbstring.func_overload</code> в значение <code>0</code> в php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Очевидно, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модули PHP были установлены, но они все еще перечислены как недостающие?",
    "Please ask your server administrator to restart the web server." : "Пожалуйста, попросите вашего администратора перезапустить веб-сервер.",
    "The required %s config variable is not configured in the config.php file." : "Необходимая переменная %s не настроена в файле config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Пожалуйста, попросите администратора вашего сервера проверить конфигурацию Nextcloud.",
    "Your data directory must be an absolute path." : "Каталог данных должен быть указан в виде абсолютного пути.",
    "Check the value of \"datadirectory\" in your configuration." : "Проверьте в значение параметра «datadirectory» в файле конфигурации.",
    "Your data directory is invalid." : "Каталог данных задан неверно.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Убедитесь, что в корне каталога данных присутствует файл «.ocdata».",
    "Action \"%s\" not supported or implemented." : "Действие «%s» не поддерживается или не реализовано.",
    "Authentication failed, wrong token or provider ID given" : "Ошибка аутентификации, неверный токен или идентификатор провайдера",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Отсутствуют параметры для завершения запроса. Отсутствующие параметры: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Идентификатор «%1$s» уже поставщиком услуг межсерверного обмена «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Провайдер облачной федерации с идентификатором: \"%s\" не существует.",
    "Could not obtain lock type %d on \"%s\"." : "Не удалось получить блокировку типа %d для «%s»",
    "Storage unauthorized. %s" : "Хранилище неавторизовано. %s",
    "Storage incomplete configuration. %s" : "Неполная конфигурация хранилища.  %s",
    "Storage connection error. %s" : "Ошибка подключения к хранилищу. %s",
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
    "Free prompt" : "Свободная подсказка",
    "Runs an arbitrary prompt through the language model." : "Запускает произвольное приглашение через языковую модель.",
    "Generate headline" : "Сгенерировать заголовок",
    "Generates a possible headline for a text." : "Генерирует возможный заголовок для текста.",
    "Summarize" : "Обобщить",
    "Summarizes text by reducing its length without losing key information." : "Обобщает текст, сокращая его длину без потери ключевой информации.",
    "Extract topics" : "Извлечь темы",
    "Extracts topics from a text and outputs them separated by commas." : "Извлекает темы из текста и выводит их через запятую.",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файлы приложения %1$s не были заменены корректно. Удостоверьтесь, что устанавливаемая версия этого приложения совместима с версией сервера.",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Для доступа к этому параметру необходимо состоять в группе администраторов, суб-администраторов или иметь специальные права",
    "Logged in user must be an admin or sub admin" : "Вошедший в систему пользователь должен обладать правами администратора или суб-администратора",
    "Logged in user must be an admin" : "Вошедший в систему пользователь должен обладать правами администратора",
    "Full name" : "Полное имя",
    "Unknown user" : "Неизвестный пользователь",
    "Enter the database username and name for %s" : "Укажите имя пользователя и название базы данных %s",
    "Enter the database username for %s" : "Укажите имя пользователя базы данных %s",
    "MySQL username and/or password not valid" : "Неверное имя пользователя и/или пароль для подключения к MySQL",
    "Oracle username and/or password not valid" : "Неверное имя пользователя и/или пароль Oracle",
    "PostgreSQL username and/or password not valid" : "Неверное имя пользователя и/или пароль PostgreSQL",
    "Set an admin username." : "Задать имя пользователя для администратора.",
    "Sharing %s failed, because this item is already shared with user %s" : "Не удалось поделиться %s, так как элемент находится в общем доступе у %s",
    "The username is already being used" : "Имя пользователя уже используется",
    "Could not create user" : "Не удалось создать пользователя",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "В имени пользователя допускаются следующие символы: «a–z», «A–Z», «0–9» и «_.@-'»",
    "A valid username must be provided" : "Укажите допустимое имя пользователя",
    "Username contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробел в начале или в конце",
    "Username must not consist of dots only" : "Имя пользователя должно состоять не только из точек",
    "Username is invalid because files already exist for this user" : "Это имя не может быть использовано, файлы этого пользователя уже существуют",
    "User disabled" : "Пользователь отключен",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Требуется как минимум libxml2 версии 2.7.0. На данный момент установлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Для исправления этой ошибки обновите версию libxml2 и перезапустите ваш веб-сервер.",
    "PostgreSQL >= 9 required." : "Требуется PostgreSQL версии 9 или более новый.",
    "Please upgrade your database version." : "Обновите базу данных.",
    "Your data directory is readable by other users." : "Каталог данных доступен для чтения другим пользователям.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Измените права доступа на 0770, чтобы другие пользователи не могли получить список файлов этого каталога."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
